km3pipe.logger.LogIO
====================

.. currentmodule:: km3pipe.logger

.. autoclass:: LogIO

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~LogIO.__init__
      ~LogIO.connect
      ~LogIO.send
   
   

   
   
   